<?php
/**
 * Functions for building out the Reading Time settings page.
 *
 * @package Uli_Reading_Time_WP
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

global $reading_time_wp;

$uli_rt_reading_time_options = get_option( 'uli_rt_reading_time_options' );

$ulirt_post_type_args = array(
	'public' => true,
);

$ulirt_post_type_args = apply_filters( 'ulirt_post_type_args', $ulirt_post_type_args );

$ulirt_post_types = get_post_types( $ulirt_post_type_args, 'object' );

if ( isset( $_POST['ulirt_reading_time_hidden'] ) && check_admin_referer( 'ulirt_reading_time_settings' ) && 'Y' == $_POST['ulirt_reading_time_hidden'] ) {
	// Form data sent.
	$reading_time_label             = isset( $_POST['rt_reading_time_label'] ) ? wp_kses( wp_unslash( $_POST['rt_reading_time_label'] ), $reading_time_wp->rtwp_kses ) : '';
	$reading_time_postfix           = isset( $_POST['rt_reading_time_postfix'] ) ? wp_kses( wp_unslash( $_POST['rt_reading_time_postfix'] ), $reading_time_wp->rtwp_kses ) : '';
	$reading_time_postfix_singular  = isset( $_POST['rt_reading_time_postfix_singular'] ) ? wp_kses( wp_unslash( $_POST['rt_reading_time_postfix_singular'] ), $reading_time_wp->rtwp_kses ) : '';
	$reading_time_wpm               = isset( $_POST['rt_reading_time_wpm'] ) ? sanitize_text_field( wp_unslash( $_POST['rt_reading_time_wpm'] ) ) : '';
	$reading_time_check             = isset( $_POST['rt_reading_time_check'] ) ? true : false;
	$reading_time_check_excerpt     = isset( $_POST['rt_reading_time_check_excerpt'] ) ? true : false;
	$reading_time_exclude_images    = isset( $_POST['rt_reading_time_images'] ) ? true : false;
	$reading_time_remove_from_yoast = isset( $_POST['rt_reaading_time_remove_from_yoast'] ) ? true : false;
	$reading_time_shortcodes        = isset( $_POST['rt_reading_time_shortcodes'] ) ? true : false;

	if ( isset( $_POST['ulirt_reading_time_post_types'] ) ) {
		foreach ( $_POST['ulirt_reading_time_post_types'] as $key => $value ) {
			if ( $value ) {
				$reading_time_post_types[ sanitize_text_field( $key ) ] = true;
			}
		}
	}

	$update_options = array(
		'label'              => $reading_time_label,
		'postfix'            => $reading_time_postfix,
		'postfix_singular'   => $reading_time_postfix_singular,
		'wpm'                => (float) $reading_time_wpm,
		'before_content'     => $reading_time_check,
		'before_excerpt'     => $reading_time_check_excerpt,
		'exclude_images'     => $reading_time_exclude_images,
		'remove_from_yoast'  => $reading_time_remove_from_yoast,
		'post_types'         => $reading_time_post_types,
		'include_shortcodes' => $reading_time_shortcodes,
	);

	update_option( 'uli_rt_reading_time_options', $update_options );

	?>
	<div class="updated"><p><strong><?php echo esc_html( __( 'Options saved.', 'uli-reading-time-wp' ) ); ?></strong></p></div>
	<?php
} else {
	// Normal page display.
	$reading_time_label              = isset( $uli_rt_reading_time_options['label'] ) ? esc_html( $uli_rt_reading_time_options['label'] ) : '';
	$reading_time_postfix            = isset( $uli_rt_reading_time_options['postfix'] ) ? esc_html( $uli_rt_reading_time_options['postfix'] ) : '';
	$reading_time_postfix_singular   = isset( $uli_rt_reading_time_options['postfix_singular'] ) ? esc_html( $uli_rt_reading_time_options['postfix_singular'] ) : '';
	$reading_time_wpm                = isset( $uli_rt_reading_time_options['wpm'] ) ? esc_html( $uli_rt_reading_time_options['wpm'] ) : '';
	$reading_time_check              = isset( $uli_rt_reading_time_options['before_content'] ) ? $this->ulirt_convert_boolean( $uli_rt_reading_time_options['before_content'] ) : false;
	$reading_time_check_excerpt      = isset( $uli_rt_reading_time_options['before_excerpt'] ) ? $this->ulirt_convert_boolean( $uli_rt_reading_time_options['before_excerpt'] ) : false;
	$reading_time_exclude_images     = isset( $uli_rt_reading_time_options['exclude_images'] ) ? $uli_rt_reading_time_options['exclude_images'] : false;
	$reading_time_remove_from_yoast  = isset( $uli_rt_reading_time_options['remove_from_yoast'] ) ? $uli_rt_reading_time_options['remove_from_yoast'] : false;

	

	if ( isset( $uli_rt_reading_time_options['post_types'] ) ) {
		$reading_time_post_types = $uli_rt_reading_time_options['post_types'];
    } elseif ( !isset( $uli_rt_reading_time_options['post_types'] ) || NULL === $uli_rt_reading_time_options['post_types'] ) {
		$reading_time_post_types = array();
	} else {
		// set defaults that have always been there for backwards compat until users set their own.
		$reading_time_post_types = array();

		foreach ( $ulirt_post_types as $post_type_option ) {
			if ( 'attachment' === $post_type_option->name ) {
				continue;
			}
			$reading_time_post_types[ $post_type_option->name ] = true;
		}
	}
	if ( isset( $uli_rt_reading_time_options['include_shortcodes'] ) ) {
		$reading_time_shortcodes = $uli_rt_reading_time_options['include_shortcodes'];
	} else {
		$reading_time_shortcodes = false;
	}
}
?>



<div class="wrap">
	<?php echo '<h2>' . esc_html__( 'Uli Reading Time Settings', 'uli-reading-time-wp' ) . '</h2>'; ?>
	<div id="uli_minify-min">
		<div id="poststuff">
        	<div id="uli_minify_min_processed" class="postbox-container">
            	<div class="metabox">
    				<div class="postbox">
        				<div class="inside">
							<form name="rt_reading_time_form" method="POST">
								<input type="hidden" name="ulirt_reading_time_hidden" value="Y">
								<?php wp_nonce_field( 'ulirt_reading_time_settings' ); ?>

								<table class="form-table uli_minify-settings">
									<tbody>
										<tr>
											<th scope="row"><span class="uli_minify-label-special"><?php esc_html_e( 'Reading time label: ', 'uli-reading-time-wp' ); ?></span></th>
											<td><fieldset>
											<label for="uli_minify_min_change_cache_path">
												<p><input type="text" name="rt_reading_time_label" value="<?php echo esc_attr( $reading_time_label ); ?>" size="20"></p>
												<p class="description"><?php esc_html_e( 'This value appears before the reading time. Leave blank for none.', 'uli-reading-time-wp' ); ?></p>
											</label>
											</fieldset>
											</td>
										</tr>
										<tr>
											<th scope="row"><span class="uli_minify-label-special"><?php esc_html_e( 'Reading time postfix: ', 'uli-reading-time-wp' ); ?></span></th>
											<td><fieldset>
											<label for="uli_minify_min_change_cache_path">
												<p><input type="text" name="rt_reading_time_postfix" value="<?php echo esc_attr( $reading_time_postfix ); ?>" size="20"></p>
												<p class="description"><?php esc_html_e( ' This value appears after the reading time. Leave blank for none.', 'uli-reading-time-wp' ); ?></p>
											</label>
											</fieldset>
											</td>
										</tr>
										<tr>
											<th scope="row"><span class="uli_minify-label-special"><?php esc_html_e( 'Reading time postfix singular: ', 'uli-reading-time-wp' ); ?></span></th>
											<td><fieldset>
											<label for="uli_minify_min_change_cache_path">
												<p><input type="text" name="rt_reading_time_postfix_singular" value="<?php echo esc_attr( $reading_time_postfix_singular ); ?>" size="20"></p>
												<p><?php esc_html_e( ' This value appears after the reading time, when lecture time is 1 minute.', 'uli-reading-time-wp' ); ?></p>
											</label>
											</fieldset>
											</td>
										</tr>
										<tr>
											<th scope="row"><span class="uli_minify-label-special"><?php esc_html_e( 'Words per minute: ', 'uli-reading-time-wp' ); ?></span></th>
											<td><fieldset>
											<label for="uli_minify_min_change_cache_path">
												<p><input type="number" name="rt_reading_time_wpm" value="<?php echo esc_attr( (float) $reading_time_wpm ); ?>" size="20"></p>
												<p><?php esc_html_e( ' (defaults to 300, the average reading speed for adults)', 'uli-reading-time-wp' ); ?></p>
											</label>
											</fieldset>
											</td>
										</tr>

										<tr>
										<th scope="row"><?php esc_html_e( 'Select where should it be placed', 'uli-reading-time-wp' ); ?></th>
										<td>
										<p class="uli_minify-bold-green uli_minify-rowintro"><?php esc_html_e( 'You can set different locations', 'uli-reading-time-wp' ); ?></p>

										<fieldset>
										<label for="uli_minify_min_enable_purgemenu">
										<input type="checkbox" name="rt_reading_time_check" class="cm-toggle" <?php echo ( true == $reading_time_check ) ? 'checked' : ''; ?> size="20">
										<?php esc_html_e( 'Insert Reading Time before content', 'uli-reading-time-wp' ); ?></span></label>
										<br>

										<label for="uli_minify_preserve_settings_on_uninstall">
										<input type="checkbox" name="rt_reading_time_check_excerpt" class="cm-toggle" <?php echo ( true == $reading_time_check_excerpt ) ? 'checked' : ''; ?> size="20">
										<?php esc_html_e( 'Insert Reading Time before excerpt', 'uli-reading-time-wp' ); ?></span></label>
										<br>

										<label for="uli_minify_min_uli_minify_fix_editor">
										<input type="checkbox" name="rt_reading_time_images" class="cm-toggle" <?php echo ( true === $reading_time_exclude_images ) ? 'checked' : ''; ?> size="20">
										<?php esc_html_e( 'Exclude images from the reading time: ', 'uli-reading-time-wp' ); ?></span></label>
										<br>

										<label for="uli_minify_min_uli_minify_fix_editor">
										<input type="checkbox" name="rt_reading_time_shortcodes" class="cm-toggle" <?php echo ( true === $reading_time_shortcodes ) ? 'checked' : ''; ?> size="20">
										<?php esc_html_e( 'Include shortcodes in the reading time: ', 'uli-reading-time-wp' ); ?></span></label>
										<br>
										
										<label for="uli_minify_min_enable_purgemenu">
										<p class="uli_minify-bold-green uli_minify-rowintro"><?php esc_html_e( 'Extra settings for YOAST SEO', 'uli-reading-time-wp' ); ?></p>
										<input type="checkbox" name="rt_reaading_time_remove_from_yoast" class="cm-toggle" <?php echo ( true == $reading_time_remove_from_yoast ) ? 'checked' : ''; ?> size="20">
										<?php esc_html_e( 'Remove from SEO YOAST', 'uli-reading-time-wp' ); ?></span></label>
										<br>
										

										</fieldset></td>
										</tr>

										<tr>
										<th scope="row"><?php esc_html_e( 'Select Post Types to Display Reading Time On', 'uli-reading-time-wp' ); ?></th>
										<td>
										<p class="uli_minify-bold-green uli_minify-rowintro"><?php esc_html_e( 'You can set different post types', 'uli-reading-time-wp' ); ?></p>

										<fieldset>
										<label for="uli_minify_min_enable_purgemenu">
											<?php foreach ( $ulirt_post_types as $rtwp_post_type ) : ?>
												<p>
												<input type="checkbox" name="ulirt_reading_time_post_types[<?php echo esc_attr( $rtwp_post_type->name ); ?>]" class="cm-toggle" 
												<?php echo ( isset( $reading_time_post_types[ $rtwp_post_type->name ] ) && true === $reading_time_post_types[ $rtwp_post_type->name ] ) ? 'checked' : ''; ?> size="20">
												<?php echo esc_html__( 'Display on ', 'uli-reading-time-wp' ) . esc_html( $rtwp_post_type->label ); ?>
												</p>
											<?php endforeach; ?>

										

										</fieldset></td>
										</tr>

						

									</tbody>
								</table>


								<p class="submit">
								<input type="submit" name="Submit" class="button button-primary" value="<?php esc_html_e( 'Update Options', 'uli-reading-time-wp' ); ?>" />
								</p>
							</form>
					</div>
				</div>

				<div class="metabox">
    				<div class="postbox">
        				<div class="inside">
							<h3><?php esc_html_e( 'Help and shortcodes', 'uli-reading-time-wp' ); ?></h3>
							<div class="rt-shortcode-hint">
								<p><?php echo wp_kses_post( __( 'Shortcode: <code>[ulirt_reading_time label="Reading Time:" postfix="minutes" postfix_singular="minute"]</code>', 'uli-reading-time-wp' ) ); ?></p>
								<p><?php echo wp_kses_post( __( 'Or simply use <code>[ulirt_reading_time]</code> to return the number with no labels.', 'uli-reading-time-wp' ) ); ?></p>
								<p><?php echo wp_kses_post( __( 'Want to insert the reading time into your theme? Use <code>do_shortcode(\'[ulirt_reading_time]\')</code>.', 'uli-reading-time-wp' ) ); ?></p>
								<p><?php echo wp_kses_post( __( 'The shortcode shows the reading time for the current page/post by default. To show the reading time for another one, use the optional "post_id" attribute. For example - to show the reading time for post ID 123: <code>[ulirt_reading_time post_id="123"]</code>.', 'uli-reading-time-wp' ) ); ?></p>
							</div>
						</div>
					</div>
				</div>

			</div>
		</div>
	</div>
</div>